# Accessibility Report

### Prompts:
For each Principle of Universal Design, write 2-5 sentences or point form notes explaining which features your program adhere to that principle. If you do not have any such features you can either:

(a) Describe features that you could implement in the future that would adhere to principle or

(b) Explain why the principle does not apply to a program like yours.


## Adhering to principles of universal design:

### 1. Equitable Use
- Our app ensures equitable use for all its users by providing unbiased software that does not collect or track information.
- We do not have any bias or settings that would stigmatize users.

### 2. Flexibility in Use
- We provide a flexible app experience through our UI design.
- We do not bias for left/right handed use.
- Simple and time insensitive UI means users can go at their own pace.
- Being built on Android means we support various methods such as utilizing separate arrow keys, or emulating for a mouse and keyboard.
- Support for built-in Android voiceover for the visually impaired.
- We tested our colour scheme with various colour blindness emulation strategies to ensure that visually impared users were not left out. The dynamic theming that we implemented are also chosen based on similar principles and the user can simply find a theme that works for them out of the virtually infinte combination possibilities.

### 3. Simple and Intuitive in Use
- Maintained a simple yet elegant UI design through concise language, easy to read font, and clear colours.
- Simple design with minimal complexity besides entry pages + forward/back buttons.
- Simple language to guide users with supporting icons.

### 4. Perceptible Information
- Utilizes a colours and pictures to support perceptible information.
- High contrast theme for light/dark mode ensures that users can discern between the various buttons.
- Utilizes concise language and icons for multiple ways of perceiving information.
- Thumbnails provide an additional way to view articles.

### 5. Tolerance for Error
- Our app lacks any feature that would be considered "hazardous" for the users.
- Upon receiving invalid text/strings, we give concise feedback to the user.
- Static app does not require constant vigilance or attention.

### 6. Low Physical Effort
- Being a mobile reader app, our app requires minimal range of motion to be used.
- The only gestures necessary are "tap" and "scroll", which are universal requirements .
- We do not require multiple gestures at the same time or in any contained time-frame.

### 7. Size and Space for Approach and Use
- As mobile app developers, the only physical size and space we take up is on the device's screen.
- We ensure that no buttons or features are off the screen.
- We place buttons in easy to access locations such as the bottom, and the corners.


## Marketed Audience and Non-marketed Demographics

BinoculaRSS is marketed to a wide range of audiences, but generally anybody who wants to keep up with the news without feeling overwhelmed with clutter and information. With our simple UI design, we appeal to anyone from seniors who want to switch to a simple digital news format to students who want something easy to read. By being an RSS reader, our app remains lightweight while still providing adequate information, and more if users want. Finally, by using our bookmarks system, users can

As for demographics that are less likely to use our app, we do not provide total voice-over support for the vision impaired. Being compatible with built-in Android voice-over software could be a goal in the future to accommodate for those users. Another demographic to those who might not use our app would be those who don't have access to Android devices. However, with our "Incognito Mode", one can install the app 
